@@ -137,11 +137,11 @@ class BatchProtocol(Protocol):
 
 class BatchClientHook(AwsBaseHook):
     """
-    A client for AWS Batch services.
+    Interact with AWS Batch.
+    Provide thick wrapper around :external+boto3:py:class:`boto3.client("batch") <Batch.Client>`.
 
     :param max_retries: exponential back-off retries, 4200 = 48 hours;
         polling is only used when waiters is None
-
     :param status_retries: number of HTTP retries to get job status, 10;
         polling is only used when waiters is None
 
@@ -164,8 +164,11 @@ class BatchClientHook(AwsBaseHook):
         convenience method is provided for this, e.g. to get a random delay of
         10 sec +/- 5 sec: ``delay = BatchClient.add_jitter(10, width=5, minima=0)``
 
+    Additional arguments (such as ``aws_conn_id``) may be specified and
+    are passed down to the underlying AwsBaseHook.
+
     .. seealso::
-        - https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/batch.html
+        - :class:`airflow.providers.amazon.aws.hooks.base_aws.AwsBaseHook`
         - https://docs.aws.amazon.com/general/latest/gr/api-retries.html
         - https://aws.amazon.com/blogs/architecture/exponential-backoff-and-jitter/
     """
