@@ -18,11 +18,13 @@
 from __future__ import annotations
 
 import os.path
+import urllib.parse
 from typing import TYPE_CHECKING, Sequence
 
 from airflow.models import BaseOperator
 from airflow.providers.amazon.aws.hooks.glue import GlueJobHook
 from airflow.providers.amazon.aws.hooks.s3 import S3Hook
+from airflow.providers.amazon.aws.links.glue import GlueJobRunDetailsLink
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
@@ -58,6 +60,7 @@ class GlueJobOperator(BaseOperator):
         "job_name",
         "script_location",
         "script_args",
+        "create_job_kwargs",
         "s3_bucket",
         "iam_role_name",
     )
@@ -68,6 +71,8 @@ class GlueJobOperator(BaseOperator):
     }
     ui_color = "#ededed"
 
+    operator_extra_links = (GlueJobRunDetailsLink(),)
+
     def __init__(
         self,
         *,
@@ -77,7 +82,7 @@ class GlueJobOperator(BaseOperator):
         concurrent_run_limit: int | None = None,
         script_args: dict | None = None,
         retry_limit: int = 0,
-        num_of_dpus: int | None = None,
+        num_of_dpus: int | float | None = None,
         aws_conn_id: str = "aws_default",
         region_name: str | None = None,
         s3_bucket: str | None = None,
@@ -143,6 +148,21 @@ class GlueJobOperator(BaseOperator):
             self.wait_for_completion,
         )
         glue_job_run = glue_job.initialize_job(self.script_args, self.run_job_kwargs)
+        glue_job_run_url = GlueJobRunDetailsLink.format_str.format(
+            aws_domain=GlueJobRunDetailsLink.get_aws_domain(glue_job.conn_partition),
+            region_name=glue_job.conn_region_name,
+            job_name=urllib.parse.quote(self.job_name, safe=""),
+            job_run_id=glue_job_run["JobRunId"],
+        )
+        GlueJobRunDetailsLink.persist(
+            context=context,
+            operator=self,
+            region_name=glue_job.conn_region_name,
+            aws_partition=glue_job.conn_partition,
+            job_name=urllib.parse.quote(self.job_name, safe=""),
+            job_run_id=glue_job_run["JobRunId"],
+        )
+        self.log.info("You can monitor this Glue Job run at: %s", glue_job_run_url)
         if self.wait_for_completion:
             glue_job_run = glue_job.job_completion(self.job_name, glue_job_run["JobRunId"], self.verbose)
             self.log.info(
