@@ -62,8 +62,6 @@ class QuickSightSensor(BaseSensorOperator):
         self.aws_conn_id = aws_conn_id
         self.success_status = "COMPLETED"
         self.errored_statuses = ("FAILED", "CANCELLED")
-        self.quicksight_hook: QuickSightHook | None = None
-        self.sts_hook: StsHook | None = None
 
     def poke(self, context: Context) -> bool:
         """
@@ -72,11 +70,9 @@ class QuickSightSensor(BaseSensorOperator):
         :param context: The task context during execution.
         :return: True if it COMPLETED and False if not.
         """
-        quicksight_hook = self.get_quicksight_hook
-        sts_hook = self.get_sts_hook
         self.log.info("Poking for Amazon QuickSight Ingestion ID: %s", self.ingestion_id)
-        aws_account_id = sts_hook.get_account_number()
-        quicksight_ingestion_state = quicksight_hook.get_status(
+        aws_account_id = self.sts_hook.get_account_number()
+        quicksight_ingestion_state = self.quicksight_hook.get_status(
             aws_account_id, self.data_set_id, self.ingestion_id
         )
         self.log.info("QuickSight Status: %s", quicksight_ingestion_state)
@@ -85,9 +81,9 @@ class QuickSightSensor(BaseSensorOperator):
         return quicksight_ingestion_state == self.success_status
 
     @cached_property
-    def get_quicksight_hook(self):
+    def quicksight_hook(self):
         return QuickSightHook(aws_conn_id=self.aws_conn_id)
 
     @cached_property
-    def get_sts_hook(self):
+    def sts_hook(self):
         return StsHook(aws_conn_id=self.aws_conn_id)
